@@ -104,12 +104,13 @@ class BacklogCommand(PivotalTrackerCommand):
                 id = colored.yellow(str(story.id))
 
                 if story.estimate is None:
-                    type = story.type.upper()
-                elif story.estimate >= 0:
+                    if story.type == Story.TYPE_FEATURE:
+                        type = "{0} (?)".format(story.type.upper())
+                    else:
+                        type = story.type.upper()
+                else:
                     type = "{0} ({1:d})".format(story.type.upper(),
                             story.estimate)
-                else:
-                    type = "{0} (?)".format(story.type.upper())
 
                 name = story.name
 
@@ -170,12 +171,12 @@ class ReviewCommand(BaseReviewCommand, PivotalTrackerCommand):
         :param branch: The base branch the pull request is for.
         """
         title = prompt("Pull request title", self.git.branch.name)
-        description = raw_input("Pull request description (optional): ")
+        description = prompt("Pull request description (optional)", '')
 
         if description:
-            self.description = "{0}\n\n{1}".format(self.story.url, description)
+            description = "{0}\n\n{1}".format(self.story.url, description)
         else:
-            self.description = self.story.url
+            description = self.story.url
 
         return self.github.create_pull_request(title, description, branch)
 
